<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

if ( ! class_exists('PLG_Sendy_Woo_Checkout_Integration') ) :

	class PLG_Sendy_Woo_Checkout_Integration extends WC_Integration
	{

		public function __construct()
		{
			global $woocommerce;

			$this->id                 = 'integ-sendy-woo-checkout';
			$this->method_title       = __('TuskCode\'s Checkout for Sendy on WooCommerce', $this->id );
			$this->method_description = __('Subscribe users to Sendy Newsletter from Woo Checkout Page', $this->id );

			// Load the settings.
			$this->init_form_fields();
			$this->init_settings();

			// Define user set variables.
			$this->sendy_enabled     		= $this->get_option('sendy_enabled');
			$this->sendy_url         		= $this->get_option('sendy_url');
			$this->sendy_list        		= $this->get_option('sendy_list');
			$this->sendy_api_key     		= $this->get_option('sendy_api_key');
			$this->checkout_label    		= $this->get_option('sendy_checkbox_label');			
			$this->sendy_checkbox_default 	= $this->get_option('sendy_checkbox_default');

			add_action('woocommerce_update_options_integration_' .  $this->id, array(&$this, 'process_admin_options'));
			add_filter( 'plugin_row_meta', array( &$this, 'settings_link_to_row_meta'), 10, 2 );
			add_filter('plugin_action_links_' . PLG_SENDY_WOO_CHECKOUT_BASENAME, array( &$this, 'settings_link_to_row_meta_two'), 10, 1 );	

			if( $this->sendy_enabled == 'yes' ){
				add_action( 'woocommerce_review_order_before_submit', array( &$this, 'my_custom_checkout_field' ) );
				add_action( 'woocommerce_checkout_create_order', array( &$this, 'custom_checkout_field_update_order_meta'), 10, 2 );
				//add_action( 'woocommerce_thankyou', array( &$this,'add_to_sendy_mailer'), 20, 1 );				
				add_action( 'woocommerce_checkout_create_order', array( &$this, 'add_to_sendy_mailer'), 10, 2 );
			}
		}


		public function my_custom_checkout_field( $checkout ) {
		
			woocommerce_form_field( 'sendy_checkout_val', array(
				'type'          => 'checkbox',
				'class'         => array('form-row custom_checkbox'),
				'input_class'	=> array('woocommerce-form__input input_checkbox'),
				'required'		=> false,
				'label'         => __( $this->checkout_label )

			), $this->sendy_checkbox_default == 'yes' );
		
		}

		public function settings_link_to_row_meta( $links, $file ) { 

			if ( PLG_SENDY_WOO_CHECKOUT_BASENAME == $file ) {
				
				$url = admin_url() . 'admin.php?page=wc-settings&tab=integration&section=' . $this->id;
			
				$row_meta = array(
				  'docs'    => '<a href="' . esc_url( $url ) . '"  aria-label="' . esc_attr__( 'Plugin Additional Links', PLG_SENDY_WOO_CHECKOUT_DOMAIN ) .
				  				 '" style="color:green;">' . esc_html__( 'Settings', PLG_SENDY_WOO_CHECKOUT_DOMAIN ) . '</a>'
				);
		
				return array_merge( $links, $row_meta );
			}

			return (array) $links;
		}

		public function settings_link_to_row_meta_two( $links ) { 
			$url = admin_url() . 'admin.php?page=wc-settings&tab=integration&section=' . $this->id;
				

			$link = '<a href="' . esc_url( $url ) . '"  aria-label="' . esc_attr__( 'Plugin Additional Links', PLG_SENDY_WOO_CHECKOUT_DOMAIN ) . 
							'" style="color:green;">' . esc_html__( 'Settings', PLG_SENDY_WOO_CHECKOUT_DOMAIN ) . '</a>';
			
			$links[] = $link;

			return (array) $links;
		}

		public function custom_checkout_field_update_order_meta( $order, $data ) {
		
			$value = isset($_POST['sendy_checkout_val']) ? 'yes' : 'no'; // Set the correct values
			
			$order->update_meta_data( 'sendy_checkout_val', $value );
		}

		public function init_form_fields()
		{
			$this->form_fields = array(
				'sendy_enabled' => array(
					'title'             => __('Active', PLG_SENDY_WOO_CHECKOUT_DOMAIN ),
					'type'              => 'checkbox',
					'description'       => __('Yes / No', PLG_SENDY_WOO_CHECKOUT_DOMAIN ),
					'desc_tip'          => true,
					'default'           => 'no'
				),
				'sendy_url' => array(
					'title'             => __('Sendy URL', PLG_SENDY_WOO_CHECKOUT_DOMAIN ),
					'type'              => 'text',
					'description'       => __('URL of your Sendy installtion', PLG_SENDY_WOO_CHECKOUT_DOMAIN ),
					'desc_tip'          => true,
					'default'           => ''
				),
				'sendy_api_key' => array(
					'title'             => __('Sendy API Key', PLG_SENDY_WOO_CHECKOUT_DOMAIN),
					'type'              => 'text',
					'default'           => '',
					'desc_tip'          => true,
					'description'       => __('Add your Sendy API Key', PLG_SENDY_WOO_CHECKOUT_DOMAIN ),
				),
				'sendy_list' => array(
					'title'             => __('Sendy List ID', PLG_SENDY_WOO_CHECKOUT_DOMAIN ),
					'type'              => 'text',
					'default'           => '',
					'desc_tip'          => true,
					'description'       => __('Add ID of your Sendy list', PLG_SENDY_WOO_CHECKOUT_DOMAIN),
				),

				'sendy_checkbox_label' => array(
					'title'			 	=> __('Checkout Checkbox Label', PLG_SENDY_WOO_CHECKOUT_DOMAIN),
					'type'				=> 'text',
					'default'			=> 'Subscribe to our Newsletter',
					'desc_tip'			=> true,
					'description'		=> __('Checkbox shown on checkout page, after Terms&Conditions', PLG_SENDY_WOO_CHECKOUT_DOMAIN),
				),
				'sendy_checkbox_default' => array(
					'title'             => __('Default Checkbox Value', PLG_SENDY_WOO_CHECKOUT_DOMAIN ),
					'type'              => 'checkbox',
					'label'				=> 'Checked / Unchecked',					
					'desc_tip'          => false,
					'default'           => 'no'
				)
			);
		}


		public function add_to_sendy_mailer( $order, $data ){
	
			//global $woocommerce;
			//$order = new WC_Order($order_id);

			$is_checked = $order->get_meta('sendy_checkout_val', true, '' );
					

			if( $is_checked === 'no' )
				return;

			$url = rtrim($this->sendy_url, "/");
			$boolean = 'true';

			$sendy_data = array(
				'name' => $order->get_billing_first_name() . ' ' . $order->get_billing_last_name(),
				'email' => $order->get_billing_email(),
				'list' => trim( $this->sendy_list ),
				'api_key' => trim( $this->sendy_api_key ),
				'boolean' => 'true',
			);

			$sendy_url = $url . '/subscribe';
			
			try {
				$result = wp_remote_post($sendy_url, array('body' => $sendy_data));
				$result = $result['body'];
	
			} catch (\Throwable $th) {
				error_log('Failed to connect with Sendy');
			}


		}


		public function sanitize_settings($settings)
		{
			return $settings;
		}
	}

endif;